This will run a likelihood ratio test using the genotypes of an F1 population of tetraploids for the null of Mendelian segregation (accounting for double reduction and preferential pairing) against the alternative of segregation distortion. This is when the genotypes are assumed known.
lrt_men_g4(
x,
g1,
g2,
drbound = 1/6,
pp = TRUE,
dr = TRUE,
alpha = 0,
xi1 = 1/3,
xi2 = 1/3
)A list with the following elements
statisticThe log-likelihood ratio test statistic.
dfThe degrees of freedom.
p_valueThe p-value.
alphaThe estimated double reduction rate.
xi1The estimated preferential pairing parameter of parent 1.
xi2The estimated preferential pairing parameter of parent 2.
A vector of genotype counts. x[i] is the number of
offspring with genotype i-1.
The genotype of parent 1.
The genotype of parent 2.
The maximum rate of double reduction. A default of 1/6 is provided, which is the rate under the complete equational segregation model of meiosis.
A logical. Should we account for preferential pairing
(TRUE) or not (FALSE)?
A logical. Should we account for double reduction
(TRUE) or not (FALSE)?
If dr = FALSE, this is the known rate of double
reduction.
If pp = FALSE, this is the known preferential pairing
parameter of parent 1.
If pp = FALSE, this is the known preferential pairing
parameter of parent 2.
Some offspring genotype combinations are impossible given the parental genotypes. If these impossible genotypes combinations show up, we return a p-value of 0, a log-likelihood ratio statistic of Infinity, and missing values for all other return items. The impossible genotypes are:
g1 = 0 && g2 = 0Only offspring genotypes of 0 are possible.
g1 = 4 && g2 = 4Only offspring genotypes of 4 are possible.
g1 = 0 && g2 = 4 || g1 == 4 && g2 == 0Only offspring genotypes of 2 are possible.
g1 = 0 && g2 %in% c(1, 2, 3) || g1 = %in% c(1, 2, 3) && g2 == 0Only offspring genotypes of 0, 1, and 2 are possible.
g1 = 4 && g2 %in% c(1, 2, 3) || g1 = %in% c(1, 2, 3) && g2 == 4Only offspring genotypes of 2, 3, and 4 are possible.
When g1 = 2 or g2 = 2 (or both), the model is not identified
and those estimates (alpha, xi1, and xi2) are
meaningless. Do NOT interpret them.
The estimate of alpha (double reduction rate) IS identified as
long as at least one parent is simplex, and no parent is duplex.
However, the estimates of the double reduction rate have extremely high
variance.
David Gerard
set.seed(100)
gf <- offspring_gf_2(alpha = 1/12, xi1 = 0.2, xi2 = 0.6, p1 = 1, p2 = 0)
x <- offspring_geno(gf = gf, n = 100)
lrt_men_g4(x = x, g1 = 1, g2 = 0)
Run the code above in your browser using DataLab